@@ -3,6 +3,7 @@
 import base64
 from abc import ABC, abstractmethod
 from dataclasses import asdict, dataclass, field, fields
+from typing import Optional
 
 from requests import Response
 
@@ -71,3 +72,13 @@ class ContractEvent(ABC):
                 assert (
                     _value is not None and isinstance(_value, _type)
                 ), f'invalid {_name} value: {_value}'
+
+
+class ContractEventFactory(ABC):
+    """A factory to convert contract text to a ContractEvent object."""
+
+    @classmethod
+    @abstractmethod
+    def contract_to_event(cls, contract: dict) -> Optional[ContractEvent]:
+        """Decode contract data into event objects and handle errors."""
+        ...
