@@ -13,7 +13,8 @@ from requests import Response
 
 from .. import logger
 from ..utils import retry
-from .common import ContractEvent, ContractException, Contractor
+from .common import (ContractEvent, ContractEventFactory, ContractException,
+                     Contractor)
 from .task_contractor import TaskContractor
 
 __all__ = [
@@ -114,7 +115,7 @@ class NoticeTaskCompletionEvent(ContractEvent):
         raise NotImplementedError()
 
 
-class TaskMessageEventFactory:
+class TaskMessageEventFactory(ContractEventFactory):
 
     _CLASS_MAP: Dict[str, ContractEvent] = {
         ApplySendingDataEvent.TYPE: ApplySendingDataEvent,
@@ -124,7 +125,6 @@ class TaskMessageEventFactory:
 
     @classmethod
     def contract_to_event(cls, contract: dict) -> Optional[ContractEvent]:
-        """Decode contract data into event objects and handle errors."""
         try:
             assert contract and isinstance(contract, dict)
             event_type = contract.get('type')
@@ -139,7 +139,7 @@ class TaskMessageEventFactory:
 class TaskMessageContractor(Contractor):
     """公共合约."""
 
-    _URL = 'http://alphamed-fed-service:8080/fed-service/api/v1/message'
+    _URL = 'http://alphamed-fed-service:9080/fed-service/api/v1/message'
 
     _TASK_INSIDE = 'TaskInside'
     _TASK_FINISH = 'TaskFinish'
