@@ -246,9 +246,7 @@ class DPFedAvgScheduler(FedAvgScheduler, metaclass=ABCMeta):
             if isinstance(_event, UploadTrainingResultsEvent):
                 if _event.target != self.id:
                     continue
-                training_result = self.data_channel.receive_stream(session_id=_event.session_id,
-                                                                   source=_event.source,
-                                                                   sender_key=_event.public_key)
+                training_result = self.data_channel.receive_stream(_event)
                 buffer = io.BytesIO(training_result)
                 _new_state_dict = torch.load(buffer)
                 state_dicts[_event.source] = _new_state_dict
