@@ -17,7 +17,7 @@ from torch.nn import Module
 from torch.optim import Optimizer
 from torch.utils.data import DataLoader
 
-from .. import DEV_TASK_ID, logger
+from .. import logger
 from ..data_channel import GRPCDataChannel, SendingError
 from ..metrics_trace import MetricsTrace
 from ..perf_bench import SimplePerfBench, SimplePerfBenchResult
@@ -188,6 +188,7 @@ class FedAvgScheduler(Scheduler, metaclass=ABCMeta):
 
         self.model = None
         self.optimizer = None
+        self.example_inputs = None
 
     def _validate_config(self):
         if self.min_clients > self.max_clients:
@@ -300,6 +301,11 @@ class FedAvgScheduler(Scheduler, metaclass=ABCMeta):
         self.push_log(message='Begin to validate local context.')
         self.validate_context()
 
+        def save_example_inputs(module, input, output):
+            if self.example_inputs is None:
+                self.example_inputs = input
+        self.model.register_forward_hook(save_example_inputs)
+
     def push_log(self, message: str):
         """Push a running log message to the task manager."""
         super().push_log(message=message)
@@ -577,9 +583,7 @@ class FedAvgScheduler(Scheduler, metaclass=ABCMeta):
                 # is selected as the next aggregator and synchronise aggregator data
                 self.push_log('Current node is selected as the new aggregator.')
                 self.push_log('Begin to synchronize context with the original aggregator.')
-                data_stream = self.data_channel.receive_stream(session_id=_event.session_id,
-                                                               source=_event.source,
-                                                               sender_key=_event.public_key)
+                data_stream = self.data_channel.receive_stream(_event)
                 sync_data = AggregatorSyncData.from_bytes(data=data_stream)
                 buffer = io.BytesIO(sync_data.state_dict)
                 _new_state_dict = torch.load(buffer)
@@ -711,9 +715,7 @@ class FedAvgScheduler(Scheduler, metaclass=ABCMeta):
             if isinstance(_event, UploadTrainingResultsEvent):
                 if _event.target != self.id:
                     continue
-                training_result = self.data_channel.receive_stream(session_id=_event.session_id,
-                                                                   source=_event.source,
-                                                                   sender_key=_event.public_key)
+                training_result = self.data_channel.receive_stream(_event)
                 buffer = io.BytesIO(training_result)
                 _new_state_dict = torch.load(buffer)
                 for _key in accum_result.keys():
@@ -774,17 +776,14 @@ class FedAvgScheduler(Scheduler, metaclass=ABCMeta):
 
         # torch.jit doesn't work with a TemporaryFile
         model_file = f'{os.path.join(self._save_path, "scripted.pt")}'
-        data_loader = self.make_test_dataloader()
-        _input, _ = next(iter(data_loader))
-        model_scripted = torch.jit.trace(self.model, _input)
+        model_scripted = torch.jit.trace(self.model, self.example_inputs)
         model_scripted.save(model_file)
         model_file_path = os.path.abspath(model_file)
 
-        if self.task_id != DEV_TASK_ID or True:
-            self.contractor.notify_task_completion(aggregator=self.id,
-                                                   result=True,
-                                                   report_file=report_file_path,
-                                                   model_file=model_file_path)
+        self.contractor.notify_task_completion(aggregator=self.id,
+                                               result=True,
+                                               report_file=report_file_path,
+                                               model_file=model_file_path)
 
     def _run_as_data_owner(self):
         try:
@@ -841,9 +840,7 @@ class FedAvgScheduler(Scheduler, metaclass=ABCMeta):
             if isinstance(_event, DistributeParametersEvent):
                 if _event.target != self.id:
                     continue
-                parameters = self.data_channel.receive_stream(session_id=_event.session_id,
-                                                              source=_event.source,
-                                                              sender_key=_event.public_key)
+                parameters = self.data_channel.receive_stream(_event)
                 buffer = io.BytesIO(parameters)
                 new_state_dict = torch.load(buffer)
                 self.load_state_dict(new_state_dict)
@@ -925,6 +922,8 @@ class FedSGDScheduler(FedAvgScheduler):
                  is_centralized: bool = True):
         r"""Init.
 
+        By now, IterableDataset with no length is not supported.
+
         :args
             :min_clients
                 Minimal number of calculators for each round.
@@ -974,9 +973,13 @@ class FedSGDScheduler(FedAvgScheduler):
         # So a post check is used.
         train_loader = self.make_train_dataloader()
         self.push_log(f'train batch size = {train_loader.batch_size}')
-        self.push_log(f'train examples = {len(train_loader.dataset)}')
-        if train_loader.batch_size != len(train_loader.dataset):
-            raise ConfigError('batch size must be the total number of samples.')
+        try:
+            num_samples = len(train_loader.dataset)
+            self.push_log(f'train examples = {num_samples}')
+            if train_loader.batch_size != len(num_samples):
+                raise ConfigError('batch size must be the total number of samples.')
+        except TypeError:
+            raise ConfigError('Does not support iterable dataset with no length.')
 
     def _select_calculators(self):
         """Select calculators of a round."""
