@@ -393,9 +393,7 @@ class SecureFedAvgScheduler(FedAvgScheduler):
             if isinstance(_event, UploadTrainingResultsEvent):
                 if _event.target != self.id:
                     continue
-                training_result = self.data_channel.receive_stream(session_id=_event.session_id,
-                                                                   source=_event.source,
-                                                                   sender_key=_event.public_key)
+                training_result = self.data_channel.receive_stream(_event)
                 buffer = io.BytesIO(training_result)
                 _new_state_dict = torch.load(buffer)
                 for _key in accum_result.keys():
